//*****************************************************************************
//
// File         createNode.C
//
// Description  WireTap SDK sample C++ program to create a library node or
//              any other generic node.
//
// Copyright 2016 Autodesk, Inc.  All rights reserved.
// Use of this software is subject to the terms of the Autodesk license
// agreement provided at the time of installation or download, or which
// otherwise accompanies this software in either electronic or hard copy form.
//
//*****************************************************************************

// Please see the Wiretap Developer's Guide for an explanation of the 
// Wiretap IFFFS server nodes hierarchy.
// 

#include <WireTapClientAPI.h>
#include <stdlib.h>
#include <stdio.h>

namespace 
{
  // Global variables.  Get values from environment variables if available.
  // Defaults ("localhost" for hostName and "stonefs" for parentNodeId)
  // will work if a Wiretap server is running on your machine.
  // 
  const char *hostEnv = getenv( "WIRETAP_HOST" );
  const char *hostName = hostEnv == 0 ? "localhost" : hostEnv;
  const char *parentNodeId= getenv( "WIRETAP_PARENT_NODE_ID" );
  const char *nodeNameEnv = getenv( "WIRETAP_NODE_NAME" );
  const char *nodeName = nodeNameEnv == 0 ? "newNode" : nodeNameEnv;
  const char *nodeTypeEnv = getenv( "WIRETAP_NODE_TYPE" );
  const char *nodeType = nodeTypeEnv == 0 ? "LIBRARY" : nodeTypeEnv;
}

int main(int argc, char** argv )
{
  // Initialize the Wiretap Client API.
  //
  WireTapClient wireTapClient;
  if ( !wireTapClient.init() ) {
    printf( "Unable to initialize WireTap client API.\n" );
    return 1;
  }

  // Instantiate a server handle.
  // 
  WireTapServerId serverId( "IFFFS", hostName );
  WireTapServerHandle server( serverId );
  
  // Instantiate the parent node 
  // 
  WireTapNodeHandle parentNode( server, parentNodeId );
  
  // Create a new node of type 'nodeType'. Each Wiretap server defines a set of
  // node types (specified as string constants).
  // 
  WireTapNodeHandle newNode;
  if ( !parentNode.createNode( nodeName, nodeType, newNode ) ){
    printf( "Unable to create node %s: %s\n",
            nodeType, parentNode.lastError() );
    return 1;
  }
  else {
    printf( "New node created '%s'\n", newNode.getNodeId().id() );
  }

  return 0;
}
