#!/usr/bin/env python

#
# Wiretap SDK tool for creating a generic node.
#

import getopt
from sys import exit,argv
from libwiretapPythonClientAPI import *

def printUsage():

    print " Usage:"
    print "  -n <parent node ID>" 
    print "  -t <server-specific node type string>" 
    print "  -d <display name>" 
    print "  [-h <host name or IP address> (default = localhost)]" 

def main(argv):

  # Check the command line options for correctness.
  try:
    opts, args = getopt.getopt(argv, "h:n:t:d:")
  except getopt.GetoptError:
    printUsage()
    exit(2)

  # Declare variables (to be set from command line arguments).
  # For hostName, the default "localhost" will work if a Wiretap server 
  # is running on your machine.
  # For nodeType, "NODE" is the type defined by the IFFFS Wiretap Server
  # for generic nodes.  
  #
  hostName = "localhost"
  parentNodeId = ""
  nodeType = "NODE"
  displayName = "node"

  # Parse command line and set variables just declared.
  # 
  for opt, arg in opts:
    if opt == '-h':
      hostName = arg
    elif opt == '-n':
      parentNodeId = arg
    if opt == "-t":
      nodeType = arg
    if opt == "-d":
      displayName = arg; 

  if parentNodeId == "":
   print "Parent Node ID not specified.\n"
   printUsage()
   exit(2)

  # Initialize the Wiretap Client API.
  #
  wiretapClient = WireTapClient()
  if not wiretapClient.init():
    raise Exception( "Unable to initialize WireTap client API" )

  try:
    # Instantiate a server handle
    #
    server = WireTapServerHandle( hostName ) 

    # Instantiate the parent node
    #
    parentNode = WireTapNodeHandle( server, parentNodeId )
    node = WireTapNodeHandle()

    # Create the node.
    #
    if not parentNode.createNode( displayName, nodeType, node ): 
      raise Exception( "Unable to create node: %s" % parentNode.lastError() )

    print "Created node '%s'." % node.getNodeId().id() 

  finally:
    # Must destroy WireTapServerHandle and WireTapNodeHandle before
    # uninitializing the WireTap Client API.
    #
    node = None
    parentNode = None
    server = None

if __name__ == '__main__':
  main(argv[1:])

