#! /usr/bin/env python

# Wiretap SDK tool for destroying a node.

import getopt
from sys import exit,argv
from libwiretapPythonClientAPI import *

def printUsage():
  print "Usage:\n" \
        "-n <node Id>\n"\
        "[-h <hostname>]\n"\

def main(argv):

  # Check the command line options for correctness.
  #
  try:
    opts, args = getopt.getopt(argv, "h:n:")
  except getopt.GetoptError:
    printUsage()
    exit(2)

  # Declare variables (to be set from command line arguments).
  # For hostName, the default "localhost" will work if a Wiretap server 
  # is running on your machine.
  #
  hostName = "localhost"
  nodeId = ""

  # Parse command line and set variables just declared
  #
  for opt, arg in opts:
    if opt == '-h':
      hostName = arg
    elif opt == '-n':
      nodeId = arg

  if nodeId == "":
   print "Node ID not specified.\n"
   printUsage()
   exit(2)

  # Initialize the Wiretap Client API.
  #
  wiretapClient = WireTapClient()
  if not wiretapClient.init():
    raise Exception( "Unable to initialize WireTap client API" )

  try:
    # Instantiate a server handle
    #
    server = WireTapServerHandle( hostName )

    # Destroy the node with the specified ID.
    #
    node = WireTapNodeHandle( server, nodeId )
    if not node.destroyNode(): 
      raise Exception( "Cannot destroy node: %s" % node.lastError() )
    print "Destroyed node %s " % node.getNodeId().id() 

  finally:
    # Must destroy WireTapServerHandle and WireTapNodeHandle before
    # uninitializing the WireTap Client API.
    #
    node = None
    server = None

if __name__ == '__main__':
  main(argv[1:])

