#!/usr/bin/env python

#
# Wiretap SDK tool for obtaining the clip format associated with a clip node.
#

import getopt
from sys import exit,argv
from libwiretapPythonClientAPI import *

def printUsage():
  print "Usage:\n" \
        "-n <node Id>\n"\
        "[-h <hostname>]"

def main(argv):

  # Check the command line options for correctness.
  try:
    opts, args = getopt.getopt(argv, "h:n:")
  except getopt.GetoptError:
    printUsage()
    exit(2)

  # Declare variables (to be set from command line arguments).
  # For hostName, the default "localhost" will work if a Wiretap server 
  # is running on your machine.
  #
  hostName = "localhost"
  nodeId = ""

  # Parse command line and set variables just declared.
  for opt, arg in opts:
    if opt == '-h':
      hostName = arg
    elif opt == '-n':
      nodeId = arg

  if nodeId == "":
   print "Node ID not specified.\n"
   printUsage()
   exit(2)

  # Initialize the Wiretap Client API.
  #
  wiretapClient = WireTapClient()
  if not wiretapClient.init():
    raise Exception( "Unable to initialize WireTap client API" )

  try:
    # Instantiate a server handle
    #
    server = WireTapServerHandle( hostName )

    # Instantiate the clip node from the specified ID
    # and get its clip format.
    #
    node = WireTapNodeHandle( server, nodeId )
    format = WireTapClipFormat()
    if not node.getClipFormat( format ):
      raise Exception( "Unable to retrieve clip format: %s" % node.lastError() )

    colourSpace = format.colourSpace()

    # Display the clip formatting parameters stored in the clip format.
    #
    print "Format %s" % format.formatTag() 
    print "Width %d" % format.width() 
    print "Height %d" % format.height() 
    print "BitsPerPixel %d" % format.bitsPerPixel()   
    print "Channels %d" % format.numChannels() 
    print "BufferSize %d" % format.frameBufferSize() 
    print "PixelRatio %g" % format.pixelRatio() 
    print "FrameRate %g" % format.frameRate() 
    print ("ScanFormat %s" % 
           WireTapClipFormat.scanFormatStr( format.scanFormat() ) ) 
    if ( len( colourSpace ) > 0 ) : print "ColourSpace %s" % colourSpace
    print "MetaDataTag %s" % format.metaDataTag() 
    print "MetaDataStream %s" % format.metaData()

  finally:
    # Must destroy WireTapServerHandle and WireTapNodeHandle before
    # uninitializing the WireTap Client API.
    #
    node = None
    server = None


if __name__ == '__main__':
  main(argv[1:])

