#!/usr/bin/env python

#
# Wiretap SDK tool for obtaining the type of a node.
#

import getopt
from sys import exit,argv
from libwiretapPythonClientAPI import *

def printUsage():
  print "Usage:\n" \
        "-n <node Id>\n"\
        "[-h <hostname>]\n"\
        "[-s] print type string\n"

def main(argv):

  # Check the command line options for correctness.
  try:
    opts, args = getopt.getopt(argv, "h:n:s")
  except getopt.GetoptError:
    printUsage()
    exit(2)

  # Declare variables (to be set from command line arguments).
  # For hostName, the default "localhost" will work if a Wiretap server 
  # is running on your machine.
  #
  hostName = "localhost"
  nodeId = ""
  printString = 0

  # Parse command line and set variables just declared.
  #
  for opt, arg in opts:
    if opt == '-h':
      hostName = arg
    elif opt == '-n':
      nodeId = arg
    elif opt == '-s':
      printString = 1

  if nodeId == "":
   print "Node ID not specified.\n"
   printUsage()
   exit(2)

  # Initialize the Wiretap Client API.
  #
  wiretapClient = WireTapClient()
  if not wiretapClient.init():
    raise Exception( "Unable to initialize WireTap client API" )

  try:
    # Instantiate a server handle
    #
    server = WireTapServerHandle( hostName )

    # Instantiate the node and get its type.
    #
    node = WireTapNodeHandle( server, nodeId )

    if printString:
      type = WireTapStr()
      if not node.getNodeTypeStr( type ):
        raise Exception( "Unable to retrieve node type: %s" % node.lastError() )
      print type.c_str()

    else:
      type = WireTapInt()
      if not node.getNodeType( type ):
        raise Exception( "Unable to retrieve node type: %s" % node.lastError() )
      print int(type)

  finally:
    # Must destroy WireTapServerHandle and WireTapNodeHandle before
    # uninitializing the WireTap Client API.
    #
    node = None
    server = None

if __name__ == '__main__':
  main(argv[1:])

